registerWith static method
Registers this class as the default instance of UrlLauncherPlatform.
Implementation
static void registerWith(Registrar registrar) {
LocalImageProviderPlatform.instance = WebLocalImageProviderPlugin();
}
Registers this class as the default instance of UrlLauncherPlatform.
static void registerWith(Registrar registrar) {
LocalImageProviderPlatform.instance = WebLocalImageProviderPlugin();
}